#
# spec file for package python-flux-local
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-flux-local
Version:        7.0.0
Release:        1.1
Summary:        Set of tools for managing a flux gitops repository
License:        Apache-2.0
URL:            https://github.com/allenporter/flux-local
Source:         https://files.pythonhosted.org/packages/source/f/flux-local/flux_local-%{version}.tar.gz
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
#
BuildRequires:  %{python_module aiofiles >= 24.1.0}
BuildRequires:  %{python_module GitPython >= 3.1.43}
BuildRequires:  %{python_module mashumaro >= 3.15}
BuildRequires:  %{python_module nest-asyncio >= 1.6.0}
BuildRequires:  %{python_module PyYAML >= 6.0.2}
BuildRequires:  %{python_module python-slugify >= 8.0.4}
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 8.3.3}
BuildRequires:  %{python_module pytest-asyncio >= 0.25.0}
# /SECTION
BuildRequires:  fdupes
Requires:       python-aiofiles >= 24.1.0
Requires:       python-GitPython >= 3.1.43
Requires:       python-mashumaro >= 3.15
Requires:       python-nest-asyncio >= 1.6.0
Requires:       python-python-slugify >= 8.0.4
Requires:       python-PyYAML >= 6.0.2
# Note: flux-local provides repo testing using pytest
Requires:       python-pytest >= 8.3.3
Requires:       python-pytest-asyncio >= 0.25.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
flux-local is a python library and set of tools for managing a flux gitops
repository, with validation steps to help improve quality of commits, PRs, and
general local testing.

%prep
%autosetup -p1 -n flux_local-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/flux-local
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative flux-local

%postun
%python_uninstall_alternative flux-local

%files %{python_files}
%python_alternative %{_bindir}/flux-local
%{python_sitelib}/flux_local
%pycache_only %{python_sitelib}/flux_local/__pycache__/
%{python_sitelib}/flux_local-%{version}.dist-info

%changelog
* Fri Jan  3 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 7.0.0:
  * Breaking changes
    This release removes kyverno support. All references to command
    line options and action options related to kyverno have been
    removed and you need to remove them when upgrading. It is
    expected this feature was rarely used (and as a result, not
    worth the effort to maintain).
  * What's Changed
    There is a change to dependency tracking for HelmReleases that
    is meant to catch changes in dependencies that were previously
    ignored. Please report an issue if you see unexpected
    HelmRelease diffs.
  - Remove kyverno support by @allenporter in #818
  - Move resource diff and visitor logic to primary library
    directory by @allenporter in #819
  - Update testdata to remove invalid dependsOn reference in
    cluster8 by @allenporter in #820
  - Improve HelmRelease dependency tracking for diffs by
    @allenporter in #821
* Fri Dec 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 6.1.1:
  * What's Changed
  - Fix merging of values to override inline values last broken in 6.1.0 1
    by @allenporter in #815
  * Developer updates
  - Update devcontainer Dockerfile to jammy 20241217 by @allenporter in #814
* Fri Dec 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 6.1.0:
  * What's Changed
  - Add deep-merge of values, and allow empty values file by
    @Lingkar in #812
  * Developer updates
  - Upgrade to python 3.13 by @allenporter in #804
  - chore(deps): update codecov/codecov-action action to v5 by
    @renovate in #805
  - Apply cruft updates by @allenporter in #809
  - Apply cruft updates by @allenporter in #810
  - chore(deps): update dependency pdoc to v15.0.1 by @renovate
    in #811
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.6.2:
  * What's Changed
  - Strip attributes in List resources by @allenporter in #802
  * Developer updates
  - chore(deps): update dependency pytest-cov to v6 by @renovate
    in #800
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 6.0.1:
  * What's Changed
  - Set unique placeholder values for each substitution by
    @allenporter in #801
  * Developer updates
  - chore(deps): update dependency pdoc to v15 by @renovate in
    [#799]
* Fri Oct 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 6.0.0:
  * Breaking Changes
  - This is a breaking change that updates the format of the flux
    build command to have parity with get and diff commands.
    Example to build a single kustomziation:
    $ flux-local build ks apps --path tests/testdata/cluster/
    Example to inflate a single helm release:
    $ flux-local build hr podinfo -n podinfo --path tests/testdata/cluster
    The old behavior flux-local build tests/testdata/cluster/ can
    still be achieved with build all:
    $ flux-local build all tests/testdata/cluster/
  * What's Changed
  - chore(deps): update dependency types-pyyaml to
    v6.0.12.20240808 by @renovate in #774
  - chore(deps): update dependency ruff to v0.5.7 by @renovate in
    [#775]
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.5.7 by @renovate in #776
  - chore(deps): update docker.io/bitnami/kubectl docker tag to
    v1.31.0 by @renovate in #777
  - chore(deps): update dependency ruff to v0.6.0 by @renovate in
    [#778]
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.6.0 by @renovate in #779
  - chore(deps): update dependency ruff to v0.6.1 by @renovate in
    [#780]
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.6.1 by @renovate in #781
  - chore(deps): update ubuntu docker tag to jammy-20240808 by
    @renovate in #782
  - chore(deps): update docker.io/alpine/helm docker tag to
    v3.15.4 by @renovate in #783
  - chore(deps): update codespell-project/actions-codespell
    action to v2.1 by @renovate in #784
  - chore(deps): update dependency syrupy to v4.6.4 by @renovate
    in #785
  - chore(deps): update dependency pytest-asyncio to v0.24.0 by
    @renovate in #786
  - chore(deps): update dependency ruff to v0.6.2 by @renovate in
    [#787]
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.6.2 by @renovate in #788
  - chore(deps): update dependency syrupy to v4.7.1 by @renovate
    in #789
  - chore(deps): update dependency mypy to v1.11.2 by @renovate
    in #790
  - chore(deps): update peter-evans/create-pull-request action to
    v7 by @renovate in #791
  - chore(deps): update pre-commit hook
    charliermarsh/ruff-pre-commit to v0.6.4 by @renovate in #793
  - chore(deps): update dependency ruff to v0.6.4 by @renovate in
    [#792]
  - chore(deps): update dependency pdoc to v14.7.0 by @renovate
    in #794
  - chore(deps): update dependency pre-commit to v4 by @renovate
    in #796
  - chore(deps): update pre-commit hook
    pre-commit/pre-commit-hooks to v5 by @renovate in #797
  - Update flux build to have parity with other flux commands by
    @allenporter in #798
* Tue Sep 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package python-flux-local: set of tools and libraries for
  managing a local flux gitops repository
